==> geobase-1.0.2.tar.gz: test/vector/wkb_samples.dart <==
// ignore_for_file: lines_longer_than_80_chars

const wkbGeometries = [
  // each item has sub items
  // * HEXWKB or HEXEWKB string
  // * WKT string
  // * SRID (or 0 if unknown)

  // sample data (HEXWKB) from
  // https://postgis.net/docs/ST_AsBinary.html

  [
    '01030000000100000005000000000000000000000000000000000000000000000000000000000000000000f03f000000000000f03f000000000000f03f000000000000f03f000000000000000000000000000000000000000000000000',
    'POLYGON((0.0 0.0,0.0 1.0,1.0 1.0,1.0 0.0,0.0 0.0))',
    0,
  ],
  [
    '000000000300000001000000050000000000000000000000000000000000000000000000003ff00000000000003ff00000000000003ff00000000000003ff0000000000000000000000000000000000000000000000000000000000000',
    'POLYGON((0.0 0.0,0.0 1.0,1.0 1.0,1.0 0.0,0.0 0.0))',
    0,
  ],

  // sample data (HEXEWKB) from
  // https://postgis.net/docs/ST_AsEWKB.html

  [
    '0103000020e61000000100000005000000000000000000000000000000000000000000000000000000000000000000f03f000000000000f03f000000000000f03f000000000000f03f000000000000000000000000000000000000000000000000',
    'POLYGON((0.0 0.0,0.0 1.0,1.0 1.0,1.0 0.0,0.0 0.0))',
    4326,
  ],
  [
    '0020000003000010e600000001000000050000000000000000000000000000000000000000000000003ff00000000000003ff00000000000003ff00000000000003ff0000000000000000000000000000000000000000000000000000000000000',
    'POLYGON((0.0 0.0,0.0 1.0,1.0 1.0,1.0 0.0,0.0 0.0))',
    4326,
  ],

  // sample data (HEXEWKB) from
  // https://postgis.net/docs/using_postgis_dbmanagement.html#EWKB_EWKT
  [
    '01010000200400000000000000000000000000000000000000',
    'POINT(0.0 0.0)',
    4,
  ],

  // sample data (HEXEWKB) from
  // https://github.com/navibyte/geospatial/issues/165
  [
    '0101000020AB1000000000000000C05EC00000000000004140',
    'POINT(-123.0 34.0)',
    4267,
  ],
  [
    '0101000020E6100000B8A1164EC5725140D1650CC83FB83840',
    'POINT(69.79329254350785 24.719723227526462)',
    4326,
  ],

  // WKT sample data from "wkt_samples.dart" and converted to HEXEWKB using
  // this tool : https://rodic.fr/wp-content/uploads/2015/11/geom_converter.html
  [
    '010100000033333333333324403333333333333440',
    'POINT(10.1 20.2)',
    0,
  ],
  [
    '0102000000030000003333333333332440333333333333244033333333333334403333333333333440cdcccccccc4c3e40cdcccccccc4c3e40',
    'LINESTRING(10.1 10.1,20.2 20.2,30.3 30.3)',
    0,
  ],
  [
    '010300000001000000050000003333333333332440333333333333244033333333333334403333333333332440333333333333344033333333333334403333333333332440333333333333344033333333333324403333333333332440',
    'POLYGON((10.1 10.1,20.2 10.1,20.2 20.2,10.1 20.2,10.1 10.1))',
    0,
  ], //
  [
    '0104000000030000000101000000333333333333244033333333333324400101000000333333333333344033333333333334400101000000cdcccccccc4c3e40cdcccccccc4c3e40',
    'MULTIPOINT(10.1 10.1,20.2 20.2,30.3 30.3)',
    0,
  ],
  [
    '01050000000100000001020000000500000000000000008041400000000000002440000000000080464000000000008046400000000000002e4000000000000044400000000000002440000000000000344000000000008041400000000000002440',
    'MULTILINESTRING((35.0 10.0,45.0 45.0,15.0 40.0,10.0 20.0,35.0 10.0))',
    0,
  ],
  [
    '0106000000010000000103000000010000000500000000000000008041400000000000002440000000000080464000000000008046400000000000002e4000000000000044400000000000002440000000000000344000000000008041400000000000002440',
    'MULTIPOLYGON(((35.0 10.0,45.0 45.0,15.0 40.0,10.0 20.0,35.0 10.0)))',
    0,
  ],
  [
    '0107000000030000000101000000333333333333244033333333333334400101000000333333333333244033333333333334400102000000030000003333333333332440333333333333244033333333333334403333333333333440cdcccccccc4c3e40cdcccccccc4c3e40',
    'GEOMETRYCOLLECTION(POINT(10.1 20.2),POINT(10.1 20.2),LINESTRING(10.1 10.1,20.2 20.2,30.3 30.3))',
    0,
  ],

  // EKWB flag variations
  [
    // xy without srid
    // 01 01000000 3333333333332440 3333333333333440
    '010100000033333333333324403333333333333440',
    'POINT(10.1 20.2)',
    0,
  ],
  [
    // xyz without srid
    // 01 01000080 3333333333332440 3333333333333440 3333333333332440
    '0101000080333333333333244033333333333334403333333333332440',
    'POINT Z(10.1 20.2 10.1)',
    0,
  ],
  [
    // xym without srid
    // 01 01000040 3333333333332440 3333333333333440 3333333333333440
    '0101000040333333333333244033333333333334403333333333333440',
    'POINT M(10.1 20.2 20.2)',
    0,
  ],
  [
    // xyzm without srid
    // 01 010000C0 3333333333332440 3333333333333440 3333333333332440 3333333333333440
    '01010000C03333333333332440333333333333344033333333333324403333333333333440',
    'POINT ZM(10.1 20.2 10.1 20.2)',
    0,
  ],
  [
    // xy with srid
    // 01 01000020 E6100000 3333333333332440 3333333333333440
    '0101000020E610000033333333333324403333333333333440',
    'POINT(10.1 20.2)',
    4326,
  ],
  [
    // xyz with srid
    // 01 010000A0 E6100000 3333333333332440 3333333333333440 3333333333332440
    '01010000A0E6100000333333333333244033333333333334403333333333332440',
    'POINT Z(10.1 20.2 10.1)',
    4326,
  ],
  [
    // xym with srid
    // 01 01000060 E6100000 3333333333332440 3333333333333440 3333333333333440
    '0101000060E6100000333333333333244033333333333334403333333333333440',
    'POINT M(10.1 20.2 20.2)',
    4326,
  ],
  [
    // xyzm with srid
    // 01 010000E0 E6100000 3333333333332440 3333333333333440 3333333333332440 3333333333333440
    '01010000E0E61000003333333333332440333333333333344033333333333324403333333333333440',
    'POINT ZM(10.1 20.2 10.1 20.2)',
    4326,
  ],
];

==> geobase-1.1.0.tar.gz: test/vector/wkb_samples.dart <==
import 'package:geobase/coordinates.dart';

// ignore_for_file: lines_longer_than_80_chars

const wkbGeometries = [
  // each item has sub items
  // * HEXWKB or HEXEWKB string
  // * WKT string
  // * SRID (or 0 if unknown)
  // * expectEWKB

  // sample data (HEXWKB) from
  // https://postgis.net/docs/ST_AsBinary.html

  [
    '01030000000100000005000000000000000000000000000000000000000000000000000000000000000000f03f000000000000f03f000000000000f03f000000000000f03f000000000000000000000000000000000000000000000000',
    'POLYGON((0 0,0 1,1 1,1 0,0 0))',
    0,
    false,
    Coords.xy,
  ],
  [
    '000000000300000001000000050000000000000000000000000000000000000000000000003ff00000000000003ff00000000000003ff00000000000003ff0000000000000000000000000000000000000000000000000000000000000',
    'POLYGON((0 0,0 1,1 1,1 0,0 0))',
    0,
    false,
    Coords.xy,
  ],

  // sample data (HEXEWKB) from
  // https://postgis.net/docs/ST_AsEWKB.html

  [
    '0103000020e61000000100000005000000000000000000000000000000000000000000000000000000000000000000f03f000000000000f03f000000000000f03f000000000000f03f000000000000000000000000000000000000000000000000',
    'POLYGON((0 0,0 1,1 1,1 0,0 0))',
    4326,
    true,
    Coords.xy,
  ],
  [
    '0020000003000010e600000001000000050000000000000000000000000000000000000000000000003ff00000000000003ff00000000000003ff00000000000003ff0000000000000000000000000000000000000000000000000000000000000',
    'POLYGON((0 0,0 1,1 1,1 0,0 0))',
    4326,
    true,
    Coords.xy,
  ],

  // sample data (HEXEWKB) from
  // https://postgis.net/docs/using_postgis_dbmanagement.html#EWKB_EWKT
  [
    '01010000200400000000000000000000000000000000000000',
    'POINT(0 0)',
    4,
    true,
    Coords.xy,
  ],

  // sample data (HEXEWKB) from
  // https://github.com/navibyte/geospatial/issues/165
  [
    '0101000020AB1000000000000000C05EC00000000000004140',
    'POINT(-123 34)',
    4267,
    true,
    Coords.xy,
  ],
  [
    '0101000020E6100000B8A1164EC5725140D1650CC83FB83840',
    'POINT(69.79329254350785 24.719723227526462)',
    4326,
    true,
    Coords.xy,
  ],

  // WKT sample data from "wkt_samples.dart" and converted to HEXEWKB using
  // this tool : https://rodic.fr/wp-content/uploads/2015/11/geom_converter.html
  [
    '010100000033333333333324403333333333333440',
    'POINT(10.1 20.2)',
    0,
    false,
    Coords.xy,
  ],
  [
    '0102000000030000003333333333332440333333333333244033333333333334403333333333333440cdcccccccc4c3e40cdcccccccc4c3e40',
    'LINESTRING(10.1 10.1,20.2 20.2,30.3 30.3)',
    0,
    false,
    Coords.xy,
  ],
  [
    '010300000001000000050000003333333333332440333333333333244033333333333334403333333333332440333333333333344033333333333334403333333333332440333333333333344033333333333324403333333333332440',
    'POLYGON((10.1 10.1,20.2 10.1,20.2 20.2,10.1 20.2,10.1 10.1))',
    0,
    false,
    Coords.xy,
  ], //
  [
    '0104000000030000000101000000333333333333244033333333333324400101000000333333333333344033333333333334400101000000cdcccccccc4c3e40cdcccccccc4c3e40',
    'MULTIPOINT(10.1 10.1,20.2 20.2,30.3 30.3)',
    0,
    false,
    Coords.xy,
  ],
  [
    '01050000000100000001020000000500000000000000008041400000000000002440000000000080464000000000008046400000000000002e4000000000000044400000000000002440000000000000344000000000008041400000000000002440',
    'MULTILINESTRING((35 10,45 45,15 40,10 20,35 10))',
    0,
    false,
    Coords.xy,
  ],
  [
    '0106000000010000000103000000010000000500000000000000008041400000000000002440000000000080464000000000008046400000000000002e4000000000000044400000000000002440000000000000344000000000008041400000000000002440',
    'MULTIPOLYGON(((35 10,45 45,15 40,10 20,35 10)))',
    0,
    false,
    Coords.xy,
  ],
  [
    '0107000000030000000101000000333333333333244033333333333334400101000000333333333333244033333333333334400102000000030000003333333333332440333333333333244033333333333334403333333333333440cdcccccccc4c3e40cdcccccccc4c3e40',
    'GEOMETRYCOLLECTION(POINT(10.1 20.2),POINT(10.1 20.2),LINESTRING(10.1 10.1,20.2 20.2,30.3 30.3))',
    0,
    false,
    Coords.xy,
  ],

  // EKWB flag variations
  [
    // xy without srid
    // 01 01000000 3333333333332440 3333333333333440
    '010100000033333333333324403333333333333440',
    'POINT(10.1 20.2)',
    0,
    false,
    Coords.xy,
  ],
  [
    // xyz without srid
    // 01 01000080 3333333333332440 3333333333333440 3333333333332440
    '0101000080333333333333244033333333333334403333333333332440',
    'POINT Z(10.1 20.2 10.1)',
    0,
    true,
    Coords.xyz,
  ],
  [
    // xym without srid
    // 01 01000040 3333333333332440 3333333333333440 3333333333333440
    '0101000040333333333333244033333333333334403333333333333440',
    'POINT M(10.1 20.2 20.2)',
    0,
    true,
    Coords.xym,
  ],
  [
    // xyzm without srid
    // 01 010000C0 3333333333332440 3333333333333440 3333333333332440 3333333333333440
    '01010000C03333333333332440333333333333344033333333333324403333333333333440',
    'POINT ZM(10.1 20.2 10.1 20.2)',
    0,
    true,
    Coords.xyzm,
  ],
  [
    // xy with srid
    // 01 01000020 E6100000 3333333333332440 3333333333333440
    '0101000020E610000033333333333324403333333333333440',
    'POINT(10.1 20.2)',
    4326,
    true,
    Coords.xy,
  ],
  [
    // xyz with srid
    // 01 010000A0 E6100000 3333333333332440 3333333333333440 3333333333332440
    '01010000A0E6100000333333333333244033333333333334403333333333332440',
    'POINT Z(10.1 20.2 10.1)',
    4326,
    true,
    Coords.xyz,
  ],
  [
    // xym with srid
    // 01 01000060 E6100000 3333333333332440 3333333333333440 3333333333333440
    '0101000060E6100000333333333333244033333333333334403333333333333440',
    'POINT M(10.1 20.2 20.2)',
    4326,
    true,
    Coords.xym,
  ],
  [
    // xyzm with srid
    // 01 010000E0 E6100000 3333333333332440 3333333333333440 3333333333332440 3333333333333440
    '01010000E0E61000003333333333332440333333333333344033333333333324403333333333333440',
    'POINT ZM(10.1 20.2 10.1 20.2)',
    4326,
    true,
    Coords.xyzm,
  ],
];
